@@ -1,5 +1,5 @@
-# This code is part of Perl distribution Log-Report version 1.42.
-# The POD got stripped from this file by OODoc version 3.05.
+# This code is part of Perl distribution Log-Report version 1.44.
+# The POD got stripped from this file by OODoc version 3.06.
 # For contributors see file ChangeLog.
 
 # This software is copyright (c) 2007-2025 by Mark Overmeer.
@@ -8,13 +8,9 @@
 # the same terms as the Perl 5 programming language system itself.
 # SPDX-License-Identifier: Artistic-1.0-Perl OR GPL-1.0-or-later
 
-#oodist: *** DO NOT USE THIS VERSION FOR PRODUCTION ***
-#oodist: This file contains OODoc-style documentation which will get stripped
-#oodist: during its release in the distribution.  You can use this file for
-#oodist: testing, however the code of this development version may be broken!
 
 package Log::Report::Dispatcher::LogDispatch;{
-our $VERSION = '1.42';
+our $VERSION = '1.44';
 }
 
 use base 'Log::Report::Dispatcher';
@@ -22,7 +18,7 @@ use base 'Log::Report::Dispatcher';
 use warnings;
 use strict;
 
-use Log::Report 'log-report', syntax => 'SHORT';
+use Log::Report 'log-report', import => [ qw/__ __x error panic/ ];
 use Log::Report::Util  qw/@reasons expand_reasons/;
 
 use Log::Dispatch 2.00;
